Readme
======

.. image:: https://gitlab.com/euri10/aiosqlembic/badges/master/pipeline.svg
    :target: https://gitlab.com/euri10/aiosqlembic/-/commits/master
    :alt: pipeline status
.. image:: https://gitlab.com/euri10/aiosqlembic/badges/master/coverage.svg
    :target: https://gitlab.com/euri10/aiosqlembic/-/commits/master
    :alt: coverage report
.. image:: https://readthedocs.org/projects/aiosqlembic/badge/?version=latest
    :target: https://aiosqlembic.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Aiosqlembic aims at running database migrations powered by the awesome `aiosql <https://github.com/nackjicholson/aiosql>`_

It currently uses the also excellent `migra <https://github.com/djrobstep/migral>`_

It is in development and likely to break

Installation
------------

Run :code:`pip install aiosqlembic`

Documentation
-------------

It's here `here <https://aiosqlembic.readthedocs.io/en/latest/index.html>`_

Usage
-----

Run :code:`aiosqlembic --help`
